@@ -1,14 +1,13 @@
 package HTML::FormFu::Constraint;
-
-use strict;
-use base 'HTML::FormFu::Processor';
+$HTML::FormFu::Constraint::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Constraint;
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
+    DEBUG_CONSTRAINTS_WHEN
     debug
 );
 use Clone ();
@@ -20,10 +19,10 @@ use List::MoreUtils qw( any all );
 use List::Util qw( first );
 use Scalar::Util qw( reftype blessed );
 
-has not          => ( is => 'rw', traits => ['Chained'] );
-has force_errors => ( is => 'rw', traits => ['Chained'] );
-has when         => ( is => 'rw', traits => ['Chained'] );
-has only_on_reps => ( is => 'rw', traits => ['Chained'] );
+has not          => ( is => 'rw', traits => ['FormFuChained'] );
+has force_errors => ( is => 'rw', traits => ['FormFuChained'] );
+has when         => ( is => 'rw', traits => ['FormFuChained'] );
+has only_on_reps => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub repeatable_repeat {
     my ( $self, $repeatable, $new_block ) = @_;
@@ -274,10 +273,10 @@ sub _process_when {
             if defined $value;
     }
 
-    DEBUG_CONSTRAINTS && debug( 'WHEN_FIELDS_VALUES' => \@when_fields_value );
+    DEBUG_CONSTRAINTS_WHEN && debug( 'WHEN_FIELDS_VALUES' => \@when_fields_value );
 
     if ( !@when_fields_value ) {
-        DEBUG_CONSTRAINTS
+        DEBUG_CONSTRAINTS_WHEN
             && debug("No 'when' fields values exist - returning false");
         return 0;
     }
@@ -305,18 +304,30 @@ sub _process_when {
         }
     }
 
-    DEBUG_CONSTRAINTS && debug( "'when' value matches" => \@ok );
+    DEBUG_CONSTRAINTS_WHEN && debug( "'when' value matches" => \@ok );
 
     my $return
         = $any
         ? any { $when->{not} ? !$_ : $_ } @ok
         : all { $when->{not} ? !$_ : $_ } @ok;
 
-    DEBUG_CONSTRAINTS && debug( "'when' return value" => $return );
+    DEBUG_CONSTRAINTS_WHEN && debug( "'when' return value" => $return );
 
     return $return;
 }
 
+sub fetch_error_message {
+    my ( $self ) = @_;
+
+    my $error = HTML::FormFu::Exception::Constraint->new({
+        form      => $self->form,
+        parent    => $self->parent,
+        processor => $self,
+    });
+
+    return $error->message;
+}
+
 sub clone {
     my $self = shift;
 
@@ -529,6 +540,22 @@ C<$constraint> (the Constraint object)
 
 =back
 
+=head1 EXPERIMENTAL METHODS
+
+=head2 fetch_error_message
+
+Return value: $string
+
+Attempt to return the error message that would be used if this constraint 
+generated an error.
+
+This will generally be correct for simple constraints with a fixed message or
+which use a placeholder from a known value, such as 
+L<HTML::FormFu::Constraint::Min/min>.
+This will generally C<not> return the correct message for constraints which
+use L<HTML::FormFu::Role::Constraint::Others/others>, where the field with an
+error is not known without actually fully processing a form submission.
+
 =head1 CORE CONSTRAINTS
 
 =over
@@ -583,8 +610,6 @@ C<$constraint> (the Constraint object)
 
 =item L<HTML::FormFu::Constraint::Range>
 
-=item L<HTML::FormFu::Constraint::reCAPTCHA>
-
 =item L<HTML::FormFu::Constraint::Regex>
 
 =item L<HTML::FormFu::Constraint::Required>
@@ -597,6 +622,14 @@ C<$constraint> (the Constraint object)
 
 =back
 
+=head1 NON-CORE CONSTRAINTS AVAILABLE ON CPAN
+
+=over
+
+=item L<HTML::FormFu::Constraint::reCAPTCHA>
+
+=back
+
 =head1 CAVEATS
 
 See L<HTML::FormFu::Element::Repeatable/"Unsupported Constraints">
