@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::Email;
-
-use strict;
-use base 'HTML::FormFu::Constraint';
+$HTML::FormFu::Constraint::Email::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 use Email::Valid;
 
@@ -15,6 +15,8 @@ sub constrain_value {
     return $ok;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -32,7 +34,7 @@ method of L<Email::Valid>.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -42,3 +44,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
