@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::File::MaxSize;
-
-use strict;
-use base 'HTML::FormFu::Constraint::File::Size';
+$HTML::FormFu::Constraint::File::MaxSize::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Constraint::File::Size';
 
 sub _localize_args {
     my ($self) = @_;
@@ -9,6 +9,8 @@ sub _localize_args {
     return $self->max;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -38,8 +40,8 @@ L</max> is an alias for L</maximum>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from L<HTML::FormFu::File::Size>, 
-L<HTML::FormFu::Constraint>
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Constraint::File::Size>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
 
@@ -51,3 +53,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
