@@ -1,13 +1,14 @@
 package HTML::FormFu::Constraint::Regex;
-
+$HTML::FormFu::Constraint::Regex::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
 
 use Regexp::Common;
 
-has common => ( is => 'rw', traits => ['Chained'] );
-has regex  => ( is => 'rw', traits => ['Chained'] );
+has common   => ( is => 'rw', traits => ['FormFuChained'] );
+has regex    => ( is => 'rw', traits => ['FormFuChained'] );
+has anchored => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub constrain_value {
     my ( $self, $value ) = @_;
@@ -36,6 +37,10 @@ sub constrain_value {
         $regex = qr/.*/;
     }
 
+    if ( $self->anchored ) {
+        $regex = qr{^$regex\z};
+    }
+
     my $ok = $value =~ $regex;
 
     return $self->not ? !$ok : $ok;
@@ -78,6 +83,13 @@ C<< $RE{URI}{HTTP}{-scheme => 'https?'} >>
       - HTTP
       - { '-scheme': 'https?' }
 
+=-head2 anchored
+
+Arguments: bool
+
+If true, uses C<^> and C<\z> to anchor the L</regex> or L</common>
+to the start and end of the submitted value.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
