@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::Required;
-
-use strict;
-use base 'HTML::FormFu::Constraint';
+$HTML::FormFu::Constraint::Required::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 sub constrain_value {
     my ( $self, $value ) = @_;
@@ -9,6 +9,8 @@ sub constrain_value {
     return defined $value && length $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
