@@ -1,12 +1,14 @@
 package HTML::FormFu::Constraint::Word;
-
-use strict;
-use base 'HTML::FormFu::Constraint::Regex';
+$HTML::FormFu::Constraint::Word::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Constraint::Regex';
 
 sub regex {
     return qr/^\w*\z/;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -25,7 +27,7 @@ characters" will depend on the current locale.
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint::Regex>,
 L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -35,3 +37,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
