@@ -1,4 +1,5 @@
 package HTML::FormFu::Element::Checkbox;
+$HTML::FormFu::Element::Checkbox::VERSION = '2.00';
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -13,9 +14,13 @@ after BUILD => sub {
     my ( $self, $args ) = @_;
 
     $self->field_type('checkbox');
-    $self->reverse_multi(1);
     $self->value(1);
 
+    $self->multi_layout( [
+        'field',
+        'label',
+    ] );
+
     return;
 };
 
@@ -40,6 +45,10 @@ sub prepare_attrs {
         ? $self->get_nested_hash_value( $form->input, $self->nested_name )
         : undef;
 
+    if (defined $value and ref $value eq 'ARRAY') {
+        $value = $original if grep { $_ eq $original } @$value;
+    }
+
     if (   $submitted
         && defined $value
         && defined $original
@@ -93,9 +102,11 @@ Default Value: 1
 
 Inherited. See L<HTML::FormFu::Role::Element::Field/default_empty_value> for details.
 
-=head2 reverse_multi
+=head2 multi_layout
 
-Overrides the default value, so it's C<true>.
+Overrides the default value of 
+L<multi_layout|HTML::FormFu::Role::Element::Field/multi_layout>
+to swap the C<field> and C<label> around.
 
 =head1 SEE ALSO
 
