@@ -1,6 +1,7 @@
 package HTML::FormFu::Element::Checkboxgroup;
+$HTML::FormFu::Element::Checkboxgroup::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element';
 
 with 'HTML::FormFu::Role::Element::Group';
@@ -13,25 +14,32 @@ has input_type => (
     is      => 'rw',
     default => 'checkbox',
     lazy    => 1,
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 has reverse_group => (
     is     => 'rw',
-    traits => ['Chained'],
+    traits => ['FormFuChained'],
 );
 
 after BUILD => sub {
     my ( $self, $args ) = @_;
 
-    $self->filename('input');
-    $self->field_filename('checkboxgroup_tag');
+    $self->layout_field_filename('field_layout_checkboxgroup_field');
     $self->label_tag('legend');
     $self->container_tag('fieldset');
     $self->multi_value(1);
     $self->reverse_group(1);
     $self->input_type('checkbox');
 
+    $self->layout( [
+        'label',
+        'errors',
+        'field',
+        'comment',
+        'javascript',
+    ] );
+
     return;
 };
 
@@ -68,6 +76,7 @@ sub _prepare_id {
         my $id = $self->auto_id;
         $id =~ s/%([fn])/$string{$1}/g;
         $id =~ s/%c/ ++$$count_ref /gex;
+        $id =~ s/%v/ $option->{value} /gex;
 
         if ( defined( my $count = $self->repeatable_count ) ) {
             $id =~ s/%r/$count/g;
@@ -266,7 +275,9 @@ See L<HTML::FormFu::Role::Element::Group/value_range>.
 
 In addition to the substitutions documented by L<HTML::FormFu/auto_id>, 
 C<%c> will be replaced by an incremented integer, to ensure there are 
-no duplicated ID's.
+no duplicated ID's, and C<%v> will be replaced by the item's value to
+allow multiple elements with the same name to coexist, and their labels
+to correctly select the appropriate item.
 
     ---
     elements:
