@@ -1,6 +1,7 @@
 package HTML::FormFu::Element::ComboBox;
+$HTML::FormFu::Element::ComboBox::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element::Multi';
 
 with 'HTML::FormFu::Role::Element::ProcessOptionsFromModel';
@@ -17,11 +18,11 @@ our @DEFER_TO_SELECT = qw(
 );
 
 for my $name (@DEFER_TO_SELECT) {
-    has $name => ( is => 'rw', traits => ['Chained'] );
+    has $name => ( is => 'rw', traits => ['FormFuChained'] );
 }
 
-has select => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
-has text   => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
+has select => ( is => 'rw', traits => ['FormFuChained'], default => sub { {} } );
+has text   => ( is => 'rw', traits => ['FormFuChained'], default => sub { {} } );
 
 *default = \&value;
 
@@ -370,11 +371,11 @@ Override the auto-generated name of the select menu.
 
 Although this element inherits from L<HTML::FormFu::Element::Block>, its 
 behaviour for the methods 
-L<filter/filters|HTML::FormFu/filters>, 
-L<constraint/constraints|HTML::FormFu/constraints>, 
-L<inflator/inflators|HTML::FormFu/inflators>, 
-L<validator/validators|HTML::FormFu/validators> and 
-L<transformer/transformers|HTML::FormFu/transformers> is more like that of 
+L<filterE<sol>filters|HTML::FormFu/filters>,
+L<constraintE<sol>constraints|HTML::FormFu/constraints>,
+L<inflatorE<sol>inflators|HTML::FormFu/inflators>,
+L<validatorE<sol>validators|HTML::FormFu/validators> and
+L<transformerE<sol>transformers|HTML::FormFu/transformers> is more like that of
 a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are 
 added directly to the date element, not to its child elements.
 
