@@ -1,10 +1,10 @@
 package HTML::FormFu::Element::ContentButton;
-
+$HTML::FormFu::Element::ContentButton::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends "HTML::FormFu::Element";
-with 'HTML::FormFu::Role::Element::Field';
-with "HTML::FormFu::Role::Element::SingleValueField";
+with 'HTML::FormFu::Role::Element::Field',
+    'HTML::FormFu::Role::Element::SingleValueField';
 
 use HTML::FormFu::Util qw( xml_escape process_attrs );
 
@@ -14,13 +14,13 @@ has field_type => (
     is      => 'rw',
     default => 'button',
     lazy    => 1,
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 after BUILD => sub {
     my ( $self, $args ) = @_;
 
-    $self->filename('content_button');
+    $self->layout_field_filename('field_layout_contentbutton_field');
 
     return;
 };
@@ -37,31 +37,6 @@ sub render_data_non_recursive {
     return $render;
 }
 
-sub string {
-    my ( $self, $args ) = @_;
-
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
-
-    # field wrapper template - start
-
-    my $html = $self->_string_field_start($render);
-
-    # input_tag template
-
-    $html .= $self->_string_field($render);
-
-    # field wrapper template - end
-
-    $html .= $self->_string_field_end($render);
-
-    return $html;
-}
-
 sub _string_field {
     my ( $self, $render ) = @_;
 
