@@ -1,4 +1,5 @@
 package HTML::FormFu::Element::Hidden;
+$HTML::FormFu::Element::Hidden::VERSION = '2.00';
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -9,28 +10,15 @@ after BUILD => sub {
     my $self = shift;
 
     $self->field_type('hidden');
-    $self->filename('input_tag');
+    $self->container_tag(undef);
+
+    $self->layout( [
+        'field',
+    ] );
 
     return;
 };
 
-sub string {
-    my ( $self, $args ) = @_;
-
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
-
-    # input template
-
-    my $html .= $self->_string_field($render);
-
-    return $html;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
