@@ -1,13 +1,11 @@
 package HTML::FormFu::Element::Radiogroup;
+$HTML::FormFu::Element::Radiogroup::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Element::Checkboxgroup';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( append_xml_attribute process_attrs );
 
-has radiogroup_filename => ( is => 'rw', traits => ['Chained'] );
-
 after BUILD => sub {
     my $self = shift;
 
@@ -80,6 +78,10 @@ no duplicated ID's.
 
 See L<HTML::FormFu::Element::Checkboxgroup/reverse_group>.
 
+=head1 DEPRECATED METHODS
+
+=head2 radiogroup_filename
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
