@@ -1,14 +1,14 @@
 package HTML::FormFu::Element::Repeatable;
-
+$HTML::FormFu::Element::Repeatable::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element::Block';
 
 use HTML::FormFu::Util qw( DEBUG_PROCESS debug );
 use List::Util qw( first );
 use Carp qw( croak );
 
-has counter_name => ( is => 'rw', traits => ['Chained'] );
+has counter_name => ( is => 'rw', traits => ['FormFuChained'] );
 
 has _original_elements => ( is => 'rw' );
 
@@ -16,7 +16,7 @@ has increment_field_names => (
     is      => 'rw',
     default => 1,
     lazy    => 1,
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 # This attribute is currently not documented as FF::Model::HashRef
@@ -26,7 +26,7 @@ has repeatable_delimiter => (
     is      => 'rw',
     default => '_',
     lazy    => 1,
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 after BUILD => sub {
@@ -449,6 +449,10 @@ used to determine whether any element is a child of a Repeatable element.
 
 Only available after L<repeat> has been called.
 
+=head2 repeatable_count_no_inherit
+
+A non-inheriting variant of L</repeatable_count>.
+
 =head2 nested_name
 
 If the L</nested_name> attribute is set, the naming scheme of the Repeatable
@@ -570,6 +574,12 @@ L<reCAPTCHA|HTML::FormFu::Constraint::reCAPTCHA>.
 Also, the L<CallbackOnce|HTML::FormFu::Constraint::CallbackOnce> constraint
 won't work within a Repeatable block, as it wouldn't make much sense.
 
+=head2 Work-arounds
+
+See L<HTML::FormFu::Filter::ForceListValue> to address a problem with 
+L<increment_field_names> disabled, and increading the L<repeat> on the
+server-side.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from
