@@ -1,16 +1,14 @@
 package HTML::FormFu::Filter::CompoundJoin;
-{
-  $HTML::FormFu::Filter::CompoundJoin::VERSION = '1.00';
-}
+$HTML::FormFu::Filter::CompoundJoin::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
 
 with 'HTML::FormFu::Role::Filter::Compound';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR $SPACE );
 
-has join => ( is => 'rw', traits => ['Chained'] );
+has join => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
