@@ -1,16 +1,16 @@
 package HTML::FormFu::Filter::HTMLScrubber;
-
+$HTML::FormFu::Filter::HTMLScrubber::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
 
 use Clone ();
 
-has allow   => ( is => 'rw', traits => ['Chained'] );
-has comment => ( is => 'rw', traits => ['Chained'] );
-has default => ( is => 'rw', traits => ['Chained'] );
-has rules   => ( is => 'rw', traits => ['Chained'] );
-has script  => ( is => 'rw', traits => ['Chained'] );
+has allow   => ( is => 'rw', traits => ['FormFuChained'] );
+has comment => ( is => 'rw', traits => ['FormFuChained'] );
+has default => ( is => 'rw', traits => ['FormFuChained'] );
+has rules   => ( is => 'rw', traits => ['FormFuChained'] );
+has script  => ( is => 'rw', traits => ['FormFuChained'] );
 
 use HTML::Scrubber;
 
