@@ -1,17 +1,19 @@
 package HTML::FormFu::Filter::NonNumeric;
-
-use strict;
-use base 'HTML::FormFu::Filter::Regex';
+$HTML::FormFu::Filter::NonNumeric::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Filter::Regex';
 
 sub match {qr/\D+/}
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::NonNumeric
+HTML::FormFu::Filter::NonNumeric - filter removing all non-numeric characters
 
 =head1 DESCRIPTION
 
