@@ -1,7 +1,7 @@
 package HTML::FormFu::Filter::TrimEdges;
-
-use strict;
-use base 'HTML::FormFu::Filter';
+$HTML::FormFu::Filter::TrimEdges::VERSION = '2.00';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -14,13 +14,15 @@ sub filter {
     return $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::TrimEdges
+HTML::FormFu::Filter::TrimEdges - filter trimming whitespace
 
 =head1 DESCRIPTION
 
