@@ -1,6 +1,7 @@
 package HTML::FormFu::Model;
+$HTML::FormFu::Model::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::HasParent';
 
@@ -8,7 +9,7 @@ use HTML::FormFu::ObjectUtil qw( form parent );
 use Scalar::Util qw( refaddr reftype );
 use Carp qw( croak );
 
-has type => ( is => 'rw', traits => ['Chained'] );
+has type => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub default_values {
     croak "'default_values' method not implemented by Model class";
