@@ -1,4 +1,5 @@
 package HTML::FormFu::QueryType::CGI;
+$HTML::FormFu::QueryType::CGI::VERSION = '2.00';
 use Moose;
 
 extends 'HTML::FormFu::Upload';
@@ -58,7 +59,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::QueryType::CGI
+HTML::FormFu::QueryType::CGI - uploaded file
 
 =head1 METHODS
 
