@@ -1,14 +1,15 @@
 package HTML::FormFu::QueryType::Catalyst;
+$HTML::FormFu::QueryType::Catalyst::VERSION = '2.00';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 extends 'HTML::FormFu::Upload';
 
 use IO::File ();
 use Scalar::Util qw( weaken );
 
-has basename => ( is => 'rw', traits => ['Chained'] );
-has tempname => ( is => 'rw', traits => ['Chained'] );
+has basename => ( is => 'rw', traits => ['FormFuChained'] );
+has tempname => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub parse_uploads {
     my ( $class, $form, $name ) = @_;
@@ -71,7 +72,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::QueryType::Catalyst
+HTML::FormFu::QueryType::Catalyst - uploaded file
 
 =head1 DESCRIPTION
 
