@@ -1,11 +1,11 @@
 package HTML::FormFu::Role::Element::Group;
+$HTML::FormFu::Role::Element::Group::VERSION = '2.00';
 use Moose::Role;
+use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::Element::Field',
-    'HTML::FormFu::Role::Element::SingleValueField' =>
-    { -excludes => 'nested_name' },
-    'HTML::FormFu::Role::Element::ProcessOptionsFromModel',
     'HTML::FormFu::Role::Element::SingleValueField',
+    'HTML::FormFu::Role::Element::ProcessOptionsFromModel',
     'HTML::FormFu::Role::Element::Coercible';
 
 use HTML::FormFu::Attribute qw( mk_output_accessors );
@@ -15,7 +15,7 @@ use List::MoreUtils qw( none );
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
-has empty_first => ( is => 'rw', traits => ['Chained'] );
+has empty_first => ( is => 'rw', traits => ['FormFuChained'] );
 
 __PACKAGE__->mk_output_accessors(qw( empty_first_label ));
 
@@ -46,9 +46,6 @@ my @ALLOWED_OPTION_KEYS = qw(
     label_attrs
     label_attributes_xml
     label_attrs_xml
-    placeholder
-    placeholder_xml
-    placeholder_loc
 );
 
 after BUILD => sub {
@@ -226,14 +223,6 @@ sub _parse_option_hashref {
         $item->{label} = $self->form->localize( $item->{label_loc} );
     }
 
-    if ( defined $item->{placeholder_xml} ) {
-        $item->{placeholder} = literal( $item->{placeholder_xml} );
-    }
-    elsif ( defined $item->{placeholder_loc} ) {
-        $item->{placeholder}
-            = $self->form->localize( $item->{placeholder_loc} );
-    }
-
     if ( defined $item->{value_xml} ) {
         $item->{value} = literal( $item->{value_xml} );
     }
@@ -371,7 +360,6 @@ sub _quote_options {
 
     foreach my $opt (@$options) {
         $opt->{label}            = xml_escape( $opt->{label} );
-        $opt->{placeholder}      = xml_escape( $opt->{placeholder} );
         $opt->{value}            = xml_escape( $opt->{value} );
         $opt->{attributes}       = xml_escape( $opt->{attributes} );
         $opt->{label_attributes} = xml_escape( $opt->{label_attributes} );
@@ -384,42 +372,6 @@ sub _quote_options {
     }
 }
 
-sub string {
-    my ( $self, $args ) = @_;
-
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
-
-    # field wrapper template - start
-
-    my $html = $self->_string_field_start($render);
-
-    # input_tag template
-
-    $html .= $self->_string_field($render);
-
-    # field wrapper template - end
-
-    $html .= $self->_string_field_end($render);
-
-    return $html;
-}
-
-sub as {
-    my ( $self, $type, %attrs ) = @_;
-
-    return $self->_coerce(
-        type       => $type,
-        attributes => \%attrs,
-        errors     => $self->_errors,
-        package    => __PACKAGE__,
-    );
-}
-
 around clone => sub {
     my ( $orig, $self ) = @_;
 
